@@ -55,7 +55,7 @@ log = logging.getLogger(__name__)
 
 
 class Client(object):
-    __version__ = '0.3.14'
+    __version__ = '0.4'
     __protocol_version__ = '0.3'
 
     def __init__(self, config):
@@ -77,9 +77,7 @@ class Client(object):
             errormator.logging.level - minimum log level for log capture
             errormator.logging_on_error - send logs only from erroneous/slow requests (default false) 
             errormator.datastores - enable query execution tracking for various datastore layers
-            errormator.slow_request_time - (float/int) time in seconds after request is considered being slow (default 30)
-            errormator.slow_query_time - (float/int) time in seconds after datastore sql query is considered being slow (default 7)
-            errormator.datastores.sqlalchemy = default true - tries to enable sqlalchemy query logging
+            errormator.slow_request_time - (float/int) time in seconds after request is considered being slow (default 3)
             errormator.report_404 - enables 404 error logging (default False)
             errormator.report_errors - enables 500 error logging (default True)
             errormator.buffer_flush_interval - how often send data to mothership Errormator (default 5)
@@ -105,10 +103,10 @@ class Client(object):
         self.config['slow_requests'] = asbool(config.get('errormator.slow_requests', True))
         self.config['slow_request_time'] = float(config.get('errormator.slow_request.time', 3))
         self.config['slow_query_time'] = float(config.get('errormator.slow_query.time', 1))
-        if self.config['slow_request_time'] < 0.5:
-            self.config['slow_request_time'] = 0.5
-        if self.config['slow_query_time'] < 0.5:
-            self.config['slow_query_time'] = 0.5
+        if self.config['slow_request_time'] < 0.1:
+            self.config['slow_request_time'] = 0.1
+        if self.config['slow_query_time'] < 0.1:
+            self.config['slow_query_time'] = 0.1
         self.config['slow_request_time'] = datetime.timedelta(seconds=self.config['slow_request_time'])
         self.config['slow_query_time'] = datetime.timedelta(seconds=self.config['slow_query_time'])
         self.config['logging'] = asbool(config.get('errormator.logging', True))
@@ -129,7 +127,7 @@ class Client(object):
                 'REMOTE_USER', 'REMOTE_ADDR', 'SERVER_NAME', 'CONTENT_TYPE']
         environ_whitelist = aslist(config.get('errormator.environ_keys_whitelist'), ',')
         self.config['environ_keys_whitelist'].extend(environ_whitelist)
-        self.config['log_namespace_blacklist'] = aslist(config.get('errormator.log_namespace_blacklist','errormator_client.client'), ',')
+        self.config['log_namespace_blacklist'] = aslist(config.get('errormator.log_namespace_blacklist', 'errormator_client.client'), ',')
 
         self.filter_callable = config.get('errormator.filter_callable')
         if self.filter_callable:
@@ -143,8 +141,8 @@ class Client(object):
         else:
             self.filter_callable = self.data_filter
 
-        if self.config['buffer_flush_interval'] < 2:
-            self.config['buffer_flush_interval'] = 2
+        if self.config['buffer_flush_interval'] < 1:
+            self.config['buffer_flush_interval'] = 1
         # register logging
         import errormator_client.logger
         if self.config['logging']:
@@ -153,19 +151,18 @@ class Client(object):
                                       'NOTSET').lower(), logging.NOTSET)
             self.log_handler.setLevel(level)
 
-        # register datastore metrics
-        if self.config['datastores'] and self.config['slow_requests']:
+        # register slow call metrics
+        if self.config['slow_requests']:
+            self.config['timing'] = config.get('errormator.timing', {})
+            for k, v in config.items():
+                if k.startswith('errormator.timing'):
+                    try:
+                        self.config['timing'][k[18:]] = float(v)
+                    except (TypeError, ValueError), e:
+                        self.config['timing'][k[18:]] = False
+            import errormator_client.timing
+            errormator_client.timing.register_timing(self.config)
             self.datastore_handler = errormator_client.logger.register_datastores()
-            if asbool(config.get('errormator.datastores.sqlalchemy', True)):
-                try:
-                    # register sqlalchemy logger
-                    import errormator_client.datastores.sqla
-                    errormator_client.datastores.sqla.sqlalchemy_07_listener(
-                                                self.config['slow_query_time'],
-                                                self.datastore_handler)
-                except ImportError as e:
-                    log.warning(e)
-                    log.warning('Sqlalchemy older than 0.7 - logging disabled')
 
         self.endpoints = {
                           "reports": '/api/reports',
@@ -285,7 +282,7 @@ class Client(object):
         with self.report_queue_lock:
             self.report_queue.append(report_data)
         log.warning(u'%s code: %s @%s' % (http_status,
-                                          report_data.get('error_type'), url,))
+                            report_data.get('error_type'), url.decode('utf8', 'ignore'),))
         return True
 
     def py_log(self, environ, records=None, r_uuid=None, traceback=None):
@@ -335,7 +332,8 @@ class Client(object):
         report_data['report_details'][0]['end_time'] = end_time
         report_data['report_details'][0]['slow_calls'] = []
         for record in records:
-            report_data['report_details'][0]['slow_calls'].append(record.errormator_data)
+            r = getattr(record, 'errormator_data', record)
+            report_data['report_details'][0]['slow_calls'].append(r)
         with self.slow_report_queue_lock:
             self.slow_report_queue.append(report_data)
         log.info('slow request/queries detected: %s' % url)
@@ -363,10 +361,20 @@ class Client(object):
                         pass
         # provide better details for 500's
         if include_params:
-            parsed_environ['COOKIES'] = dict(req.cookies)
-            parsed_environ['GET'] = dict([(k, req.GET.getall(k)) for k in req.GET])
-            parsed_environ['POST'] = dict([(k, req.POST.getall(k))
+            try:
+                parsed_environ['COOKIES'] = dict(req.cookies)
+            except Exception as e:
+                parsed_environ['COOKIES'] = {}
+            try:
+                parsed_environ['GET'] = dict([(k, req.GET.getall(k)) for k in req.GET])
+            except Exception as e:
+                parsed_environ['GET'] = {}
+            try:
+                parsed_environ['POST'] = dict([(k, req.POST.getall(k))
                                            for k in req.POST])
+            except Exception as e:
+                parsed_environ['POST'] = {}
+                
         # figure out real ip
         if environ.get("HTTP_X_FORWARDED_FOR"):
             remote_addr = environ.get("HTTP_X_FORWARDED_FOR").split(',')[0].strip()
