@@ -3,6 +3,7 @@ import datetime
 from django.conf import settings
 from django.http import Http404
 from errormator_client.exceptions import get_current_traceback
+from errormator_client.timing import local_timing
 from errormator_client.client import Client
 import logging
 import sys
@@ -60,11 +61,14 @@ class ErrormatorMiddleware(object):
 
         # report slowness
         if self.errormator_client.config['slow_requests']:
-            # do we have slow queries ?
+            # do we have slow calls ?
             end_time = datetime.datetime.utcnow()
             delta = end_time - request.__start_time__
             records = self.errormator_client.datastore_handler.get_records()
             self.errormator_client.datastore_handler.clear_records()
+            if hasattr(local_timing, '_errormator'):
+                for record in local_timing._errormator.get_slow_calls():
+                    records.append(record)
             if (delta >= self.errormator_client.config['slow_request_time']
                 or records):
                 self.errormator_client.py_slow_report(environ,
